cli

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Overview

Package cli implements the jup command-line interface.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	// contains filtered or unexported fields
}

App owns the Cobra command tree and process-level error handling.

func New

func New(options Options) *App

New creates an application with all built-in commands registered.

func (*App) Run

func (a *App) Run(ctx context.Context, args []string) int

Run executes the requested command and returns a process exit code.

type Options

type Options struct {
	Name        string
	ProductName string
	Description string
	Version     string
	Platform    string
	Commit      string
	Stdin       io.Reader
	Stdout      io.Writer
	Stderr      io.Writer
}

Options contains the dependencies and metadata needed by the CLI.

Jump to