javaversion

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package javaversion parses the major component of Java version strings.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Major

func Major(value string) (string, error)

Major returns the Java major version from modern and legacy version forms.

func OptionalMajor

func OptionalMajor(value string) (string, error)

OptionalMajor accepts an empty version in addition to the forms Major accepts.

Types

This section is empty.

Jump to