Documentation
¶
Overview ¶
Package javaversion parses the major component of Java version strings.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OptionalMajor ¶
OptionalMajor accepts an empty version in addition to the forms Major accepts.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.